@@ -81,7 +81,9 @@ class HealpixMap(HealpixBase):
         else:
             if type(crd) is n.ndarray: assert(len(crd.shape) == 1)
             px = mk_arr(crd, dtype=n.int)
-        if px.size == 1: self.map[px] = val
+        if px.size == 1:
+            if type(val) is n.ndarray: val = mk_arr(val, dtype=self.map.dtype)
+            self.map[px] = val
         else:
             m = n.zeros_like(self.map)
             px = px.reshape(px.size,1)
@@ -101,10 +103,9 @@ class HealpixMap(HealpixBase):
             th,phi = self.px2crd(px, ncrd=2)
             self[px] = hpm[th,phi].astype(self.get_dtype())
         elif hpm.nside() > self.nside():
-            factor = hpm.nside() / self.nside()
             px = n.arange(hpm.npix())
             th,phi = hpm.px2crd(px, ncrd=2)
-            self[th,phi] = hpm[px].astype(self.get_dtype()) / factor
+            self[th,phi] = hpm[px].astype(self.get_dtype())
         else:
             if hpm.scheme() == self.scheme():
                 self.map = hpm.map.astype(self.get_dtype())
